@@ -76,6 +76,7 @@ var runInTerminalResponseStruct = RunInTerminalResponse{
 // -------- Initialize
 
 var initializeRequestString = `{"seq":1,"type":"request","command":"initialize","arguments":{"clientID":"vscode","clientName":"Visual Studio Code","adapterID":"go","pathFormat":"path","linesStartAt1":true,"columnsStartAt1":true,"supportsVariableType":true,"supportsVariablePaging":true,"supportsRunInTerminalRequest":true,"locale":"en-us"}}`
+var initializeRequestOmitDefaultsString = `{"seq":1,"type":"request","command":"initialize","arguments":{"clientID":"vscode","clientName":"Visual Studio Code","adapterID":"go","supportsVariableType":true,"supportsVariablePaging":true,"supportsRunInTerminalRequest":true,"locale":"en-us"}}`
 var initializeRequestStruct = InitializeRequest{
 	Request: *newRequest(1, "initialize"),
 	Arguments: InitializeRequestArguments{
@@ -92,6 +93,23 @@ var initializeRequestStruct = InitializeRequest{
 	},
 }
 
+var initializeRequestNotDefaultsString = `{"seq":1,"type":"request","command":"initialize","arguments":{"clientID":"vscode","clientName":"Visual Studio Code","adapterID":"go","pathFormat":"url","linesStartAt1":false,"columnsStartAt1":false,"supportsVariableType":true,"supportsVariablePaging":true,"supportsRunInTerminalRequest":true,"locale":"en-us"}}`
+var initializeRequestNotDefaultsStruct = InitializeRequest{
+	Request: *newRequest(1, "initialize"),
+	Arguments: InitializeRequestArguments{
+		ClientID:                     "vscode",
+		ClientName:                   "Visual Studio Code",
+		AdapterID:                    "go",
+		PathFormat:                   "url",
+		LinesStartAt1:                false,
+		ColumnsStartAt1:              false,
+		SupportsVariableType:         true,
+		SupportsVariablePaging:       true,
+		SupportsRunInTerminalRequest: true,
+		Locale:                       "en-us",
+	},
+}
+
 var initializeResponseString = `{"seq":1,"type":"response","request_seq":2,"command":"initialize","success":true,"body":{"supportsConfigurationDoneRequest":true,"supportsSetVariable":true}}`
 var initializeResponseStruct = InitializeResponse{
 	Response: *newResponse(1, 2, "initialize", true),
@@ -815,15 +833,16 @@ func Test_DecodeProtocolMessage(t *testing.T) {
 		// ProtocolMessage
 		{``, msgIgnoredOnError, "unexpected end of JSON input"},
 		{`,`, msgIgnoredOnError, "invalid character ',' looking for beginning of value"},
-		{`{}`, msgIgnoredOnError, "ProtocolMessage type '' is not supported"},
-		{`{"a": 1}`, msgIgnoredOnError, "ProtocolMessage type '' is not supported"},
-		{`{"type":"foo", "seq": 2}`, msgIgnoredOnError, "ProtocolMessage type 'foo' is not supported"},
+		{`{}`, msgIgnoredOnError, "ProtocolMessage type '' is not supported (seq: 0)"},
+		{`{"a": 1}`, msgIgnoredOnError, "ProtocolMessage type '' is not supported (seq: 0)"},
+		{`{"type":"foo", "seq": 2}`, msgIgnoredOnError, "ProtocolMessage type 'foo' is not supported (seq: 2)"},
 		// Request
-		{`{"type":"request"}`, msgIgnoredOnError, "Request command '' is not supported"},
+		{`{"type":"request"}`, msgIgnoredOnError, "Request command '' is not supported (seq: 0)"},
 		{cancelRequestString, &cancelRequestStruct, noError},
 		{runInTerminalRequestString, &runInTerminalRequestStruct, noError},
 		{initializeRequestString, &initializeRequestStruct, noError},
-		{initializeRequestString, &initializeRequestStruct, noError},
+		{initializeRequestOmitDefaultsString, &initializeRequestStruct, noError},
+		{initializeRequestNotDefaultsString, &initializeRequestNotDefaultsStruct, noError},
 		{configurationDoneRequestString, &configurationDoneRequestStruct, noError},
 		{launchRequestString, &launchRequestStruct, noError},
 		{attachRequestString, &attachRequestStruct, noError},
@@ -863,12 +882,11 @@ func Test_DecodeProtocolMessage(t *testing.T) {
 		{readMemoryRequestString, &readMemoryRequestStruct, noError},
 		{disassembleRequestString, &disassembleRequestStruct, noError},
 		// Response
-		{`{"type":"response","success":true}`, msgIgnoredOnError, "Response command '' is not supported"},
+		{`{"type":"response","success":true, "seq": 77}`, msgIgnoredOnError, "Response command '' is not supported (seq: 77)"},
 		{errorResponseString, &errorResponseStruct, noError},
 		{cancelResponseString, &cancelResponseStruct, noError},
 		{runInTerminalResponseString, &runInTerminalResponseStruct, noError},
 		{initializeResponseString, &initializeResponseStruct, noError},
-		{initializeResponseString, &initializeResponseStruct, noError},
 		{configurationDoneResponseString, &configurationDoneResponseStruct, noError},
 		{launchResponseString, &launchResponseStruct, noError},
 		{attachResponseString, &attachResponseStruct, noError},
@@ -908,7 +926,7 @@ func Test_DecodeProtocolMessage(t *testing.T) {
 		{readMemoryResponseString, &readMemoryResponseStruct, noError},
 		{disassembleResponseString, &disassembleResponseStruct, noError},
 		// Event
-		{`{"type":"event"}`, msgIgnoredOnError, "Event event '' is not supported"},
+		{`{"type":"event", "seq": 8}`, msgIgnoredOnError, "Event event '' is not supported (seq: 8)"},
 		{initializedEventString, &initializedEventStruct, noError},
 		{stoppedEventString, &stoppedEventStruct, noError},
 		{continuedEventString, &continuedEventStruct, noError},
